==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/zh_CN.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "您无法移除您自己的读取权限。",
    "Team folders" : "团队文件夹",
    "Admin configured folders shared with everyone in a team" : "管理员配置的文件夹，与团队中所有成员共享",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理员已配置好与团队中的每个人共用的文件夹。\n\n可以在管理设置中的 *团队文件夹* 里对文件夹进行配置。\n\n创建文件夹之后，管理员可以给文件夹设备一个或多个团队的读取权限，控制他们的写入/共享权限，并为文件夹分配配额。\n从 Hub 10/Nextcloud 31 开始，管理员必须是团队的一员，才能指派团队文件夹。",
    "Unset" : "取消设置",
    "Denied (Inherited permission)" : "拒绝（继承的权限）",
    "Allowed (Inherited permission)" : "允许（继承的权限）",
    "Denied" : "拒绝",
    "Allowed" : "允许",
    "Access denied" : "访问被拒绝",
    "Access allowed" : "访问被允许",
    "Inherit permission" : "继承权限",
    "Deny" : "禁止",
    "Allow" : "允许",
    "Group" : "群组",
    "Team" : "团队",
    "Team folder" : "团队文件夹",
    "Read" : "读取",
    "Write" : "写入",
    "Create" : "创建",
    "Delete" : "删除",
    "Share" : "共享",
    "You" : "您",
    "Remove access rule" : "移除访问规则",
    "Add advanced permission rule" : "添加高级权限规则",
    "Select a user or group" : "选择用户或群组",
    "Open Team folder" : "打开团队文件夹",
    "Permission denied. User does not have sufficient permissions." : "没有权限。用户权限不足。",
    "Unexpected status from server" : "服务器状态异常",
    "List of Team folders." : "团队文件夹列表。",
    "No Team folders yet" : "尚无团队文件夹",
    "Team folders will show up here" : "团队文件夹将在这里显示",
    "Add group" : "添加群组",
    "Default" : "默认",
    "Unlimited" : "无限制",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "您确定要删除“{folderName}”和所有里面的文件吗？此操作无法撤销",
    "Delete \"{folderName}\"?" : "删除“{folderName}”吗？",
    "Team folder admin delegation" : "团队文件夹代理管理员",
    "They will have access to all Team folders." : "这些用户可以访问所有的团队文件夹。",
    "They will only have access to Team folders for which they have advanced permissions." : "他们只能访问对他们授予了高级权限的团队文件夹。",
    "Group or team" : "群组或团队",
    "Folder name" : "文件夹名称",
    "Quota" : "配额",
    "Advanced Permissions" : "高级权限",
    "Previous" : "上一个",
    "Next" : "下一个",
    "User" : "用户",
    "Unknown" : "未知",
    "Users/groups that can manage" : "可以管理以下内容的用户/群组",
    "None" : "无",
    "No other groups or teams available" : "没有其他群组或团队了",
    "No other groups available" : "没有其他群组了",
    "{displayName} (team)" : "{displayName}（团队）",
    "Add group or team" : "添加群组或团队",
    "{size} used" : "已使用 {size}",
    "Other …" : "其它 ...",
    "You can not remove your own read permission." : "您无法移除自己的读取权限。",
    "Group folders" : "群组文件夹",
    "Admin configured folders shared with everyone in a group" : "管理员配置的文件夹，与群组中所有成员共享",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理员已配置好与群组中的每个人共用的文件夹。\n\n可以从管理设置中的 *群组文件夹* 对文件夹进行配置。\n\n创建文件夹后，管理员可以授权一个或多个群组访问该文件夹，控制写入/共享权限，并为该文件夹分配配额。",
    "Group folder" : "群组文件夹",
    "Open group folder" : "打开群组文件夹",
    "List of group folders." : "群组文件夹列表。",
    "No group folders yet" : "尚无群组文件夹",
    "Group folders will show up here" : "群组文件夹将在这里显示",
    "Group folder admin delegation" : "群组文件夹代理管理员",
    "They will have access to all group folders." : "他们可以访问所有的群组文件夹。",
    "They will only have access to group folders for which they have advanced permissions." : "他们只能访问对他们授予了高级权限的群组文件夹。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理员已配置好与团队中的每个人共用的文件夹。\n\n可以从管理设置中的 *团队文件夹* 对文件夹进行配置。\n\n创建文件夹后，管理员可以授权一个或多个团队访问该文件夹，控制写入/共享权限，并为该文件夹分配配额。"
},
"nplurals=1; plural=0;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/zh_CN.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "您无法移除您自己的读取权限。",
    "Team folders" : "团队文件夹",
    "Unset" : "取消设置",
    "Denied (Inherited permission)" : "拒绝（继承的权限）",
    "Allowed (Inherited permission)" : "允许（继承的权限）",
    "Denied" : "拒绝",
    "Allowed" : "允许",
    "Access denied" : "访问被拒绝",
    "Access allowed" : "访问被允许",
    "Inherit permission" : "继承权限",
    "Deny" : "禁止",
    "Allow" : "允许",
    "Group" : "群组",
    "Team" : "团队",
    "Team folder" : "团队文件夹",
    "Read" : "读取",
    "Write" : "写入",
    "Create" : "创建",
    "Delete" : "删除",
    "Share" : "共享",
    "You" : "您",
    "Remove access rule" : "移除访问规则",
    "Add advanced permission rule" : "添加高级权限规则",
    "Select a user or group" : "选择用户或群组",
    "Open Team folder" : "打开团队文件夹",
    "Permission denied. User does not have sufficient permissions." : "没有权限。用户权限不足。",
    "Unexpected status from server" : "服务器状态异常",
    "List of Team folders." : "团队文件夹列表。",
    "No Team folders yet" : "尚无团队文件夹",
    "Team folders will show up here" : "团队文件夹将在这里显示",
    "Add group" : "添加群组",
    "Default" : "默认",
    "Unlimited" : "无限制",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "您确定要删除“{folderName}”和所有里面的文件吗？此操作无法撤销",
    "Delete \"{folderName}\"?" : "删除“{folderName}”吗？",
    "Team folder admin delegation" : "团队文件夹代理管理员",
    "They will have access to all Team folders." : "这些用户可以访问所有的团队文件夹。",
    "They will only have access to Team folders for which they have advanced permissions." : "他们只能访问对他们授予了高级权限的团队文件夹。",
    "Group or team" : "群组或团队",
    "Folder name" : "文件夹名称",
    "Quota" : "配额",
    "Advanced Permissions" : "高级权限",
    "Previous" : "上一个",
    "Next" : "下一个",
    "User" : "用户",
    "Unknown" : "未知",
    "Users/groups that can manage" : "可以管理以下内容的用户/群组",
    "None" : "无",
    "No other groups or teams available" : "没有其他群组或团队了",
    "No other groups available" : "没有其他群组了",
    "{displayName} (team)" : "{displayName}（团队）",
    "Add group or team" : "添加群组或团队",
    "{size} used" : "已使用 {size}",
    "Other …" : "其它 ...",
    "You can not remove your own read permission." : "您无法移除自己的读取权限。",
    "Group folders" : "群组文件夹",
    "Admin configured folders shared with everyone in a group" : "管理员配置的文件夹，与群组中所有成员共享",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理员已配置好与群组中的每个人共用的文件夹。\n\n可以从管理设置中的 *群组文件夹* 对文件夹进行配置。\n\n创建文件夹后，管理员可以授权一个或多个群组访问该文件夹，控制写入/共享权限，并为该文件夹分配配额。",
    "Group folder" : "群组文件夹",
    "Open group folder" : "打开群组文件夹",
    "List of group folders." : "群组文件夹列表。",
    "No group folders yet" : "尚无群组文件夹",
    "Group folders will show up here" : "群组文件夹将在这里显示",
    "Group folder admin delegation" : "群组文件夹代理管理员",
    "They will have access to all group folders." : "他们可以访问所有的群组文件夹。",
    "They will only have access to group folders for which they have advanced permissions." : "他们只能访问对他们授予了高级权限的群组文件夹。",
    "Admin configured folders shared with everyone in a team" : "管理员配置的文件夹，与团队中所有成员共享",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理员已配置好与团队中的每个人共用的文件夹。\n\n可以从管理设置中的 *团队文件夹* 对文件夹进行配置。\n\n创建文件夹后，管理员可以授权一个或多个团队访问该文件夹，控制写入/共享权限，并为该文件夹分配配额。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理员已配置好与团队中的每个人共用的文件夹。\n\n可以在管理设置中的 *团队文件夹* 里对文件夹进行配置。\n\n创建文件夹之后，管理员可以给文件夹设备一个或多个团队的读取权限，控制他们的写入/共享权限，并为文件夹分配配额。\n从 Hub 10/Nextcloud 31 开始，管理员必须是团队的一员，才能指派团队文件夹。"
},
"nplurals=1; plural=0;");
